/*
 * Copyright (C) 2011 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.scope;

import org.eiichiro.jazzmaster.Builtin;
import org.eiichiro.jazzmaster.Description;
import org.eiichiro.jazzmaster.inject.Name;

/**
 * Built-in pseudo-{@link Context} implementation corresponding to the 
 * {@link Prototype} scope.
 * {@code PrototypeContext} does not hold any component in the instance, so 
 * {@code #get(Description)} method always returns <code>null</code> and 
 * {@code #put(Description, Object)} method does no-op.
 * 
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Builtin
@Singleton(eager=true)
@Name("org.eiichiro.jazzmaster.scope.PrototypeContext")
public class PrototypeContext implements Context {

	/**
	 * Always returns <code>null</code>.
	 * 
	 * @param <T> The component type.
	 * @param description The description corresponding to the component.
	 * @return <code>null</code>.
	 */
	public <T> T get(Description<T> description) {
		return null;
	}

	/**
	 * no-op.
	 * 
	 * @param <T> The component type.
	 * @param description The description corresponding to the component.
	 * @param component The component to be put.
	 */
	public <T> void put(Description<T> description, T component) {}

}
